package service

import (
	"fmt"
	"iot_manager_service/app/device/dao"
	"iot_manager_service/app/device/model"
	"iot_manager_service/util"
	"time"
)

// 中间件管理服务
var GatewayRelationService = new(gatewayRelationService)

type gatewayRelationService struct{}

func (s *gatewayRelationService) Get(id int) (*dao.GatewayRelation, *util.Errors) {
	// 创建查询实例
	relation := &dao.GatewayRelation{
		ID: id,
	}
	err := relation.Get()
	if err != nil {
		return nil, util.FailResponse(err.Error(), nil)
	}
	return relation, nil
}

func (s *gatewayRelationService) Create(req *model.GatewayDetail) *util.Errors {
	device := req.Gateway
	if device.TenantId == "" {
		device.TenantId = "000000" // todo: 使用登录态
	}
	device.UpdateUser = "TODO" // todo: 使用登录态
	device.UpdateTime = time.Now()
	if device.LampPoleId != 0 {
		lampPole, err := LampPoleService.GetOne(device.LampPoleId)
		if err == nil {
			device.LampLat = lampPole.PoleLat
			device.LampLng = lampPole.PoleLng
			device.LampPoleName = lampPole.PoleName
			device.LampPoleSn = lampPole.PoleSN
			device.LampPoleLocation = lampPole.InstallLocation
		} else {
			fmt.Printf("LampPoleService.GetOne err = %v \n", err)
		}
	}

	if device.ID == 0 {
		device.CreateTime = time.Now()
		device.CreateUser = "TODO" // todo: 使用登录态

		if device.IsExistedBySN() {
			fmt.Printf("Create IsExistedBySN \n")
			return util.ParamsInvalidResponse(model.RepeatedPrompts, nil)
		}
		fmt.Printf("device = %+v \n", device)
		if err := device.Create(); err != nil {
			fmt.Printf("Create err = %s \n", err.Error())
			return util.FailResponse(err.Error(), nil)
		}
		return util.SuccessResponse(util.Succeeded, nil)
	}

	if err := device.Update(); err != nil {
		fmt.Printf("Update err = %s \n", err.Error())
		return util.FailResponse(err.Error(), nil)
	}

	//todo operation record
	return util.SuccessResponse(util.Succeeded, nil)
}

func (s *gatewayRelationService) Update(req *model.GatewayDetail) *util.Errors {
	device := req.Gateway
	if device.TenantId == "" {
		device.TenantId = "000000" // todo: 使用登录态
	}
	device.UpdateUser = "TODO" // todo: 使用登录态
	device.UpdateTime = time.Now()
	if device.LampPoleId != 0 {
		lampPole, err := LampPoleService.GetOne(device.LampPoleId)
		if err == nil {
			device.LampLat = lampPole.PoleLat
			device.LampLng = lampPole.PoleLng
			device.LampPoleName = lampPole.PoleName
			device.LampPoleSn = lampPole.PoleSN
			device.LampPoleLocation = lampPole.InstallLocation
		} else {
			fmt.Printf("LampPoleService.GetOne err = %v \n", err)
		}
	}

	if device.ID == 0 {
		device.CreateTime = time.Now()
		device.CreateUser = "TODO" // todo: 使用登录态

		if device.IsExistedBySN() {
			fmt.Printf("Create IsExistedBySN \n")
			return util.ParamsInvalidResponse(model.RepeatedPrompts, nil)
		}
		fmt.Printf("device = %+v \n", device)
		if err := device.Create(); err != nil {
			fmt.Printf("Create err = %s \n", err.Error())
			return util.FailResponse(err.Error(), nil)
		}
		return util.SuccessResponse(util.Succeeded, nil)
	}

	if err := device.Update(); err != nil {
		fmt.Printf("Update err = %s \n", err.Error())
		return util.FailResponse(err.Error(), nil)
	}

	//todo operation record
	return util.SuccessResponse(util.Succeeded, nil)
}

func (s *gatewayRelationService) Remove(id int) *util.Errors {
	// 创建查询实例
	device := &dao.Gateway{
		ID:         id,
		IsDeleted:  1,
		UpdateUser: "TODO", // todo 使用登录态
		UpdateTime: time.Now(),
	}

	//todo
	// service.gatewayService.CountRelation()

	//todo operation record
	err := device.Delete()
	if err != nil {
		return util.FailResponse(err.Error(), nil)
	}
	return nil
}
